#include <iostream>
#include <vector>
#include <cmath>
using namespace std;

#define NDEBUG 1
#if NDEBUG
#define debug(M)
#else
#define debug(M) do {\
		cerr << "\33[1;36mDBG " << __FILE__ << ":" << __LINE__\
			<< ": " << M << "\33[0m" << endl;\
	} while (0)
#endif

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

class Point {
	double x;
	double y;
public:
	Point();
	Point(double x, double y);

	double distance(const Point & p) const;
	double distance(const Point * p) const;
	static double distance(const Point & p, const Point & q);
	static double distance(const Point * const p, const Point * const q);
	friend ostream & operator << (ostream & os, const Point & point);
};

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////


////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

struct Node {
	Point point;
	Node * parent;
	Node * child;
	Node * sibling;
	Node * next;
	double cost;
	unsigned int id;

	Node(void);
	friend ostream & operator << (ostream & os, const Node & node);
};

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

class Tree {
	Node * const first;
	Node * last;
public:
	Tree(Node * const root);
	~Tree(void);

	Node * add(const Point & point, Node * parent);
	Node * nearest(const Point & point) const;
	std::vector<Node *> rNearest(const Point & point, double radius) const;
	friend ostream & operator << (ostream & os, const Tree & tree);
};

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////


////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

class RRTStar {
	Tree * tree;
	Node * root;
	const double RADIUS;
public:
	RRTStar(const Point & point, double radius);
	~RRTStar(void);
	void iterate(const vector<Point> & points);
	void extend(const Point & rand);
	friend ostream & operator << (ostream & os, const RRTStar & rrt);
};

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

void RRTStar::iterate(const vector<Point> & points) {
	for (unsigned int i = 1; i < points.size(); i++) {
		extend(points[i]);
	}
}

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

int main(int argc, char ** argv) {
	double x, y;
	vector<Point> vp;
	unsigned int iterator = 1;

	double radius;
	cin >> radius;

	debug("RADIUS " << radius);

	while (not cin.eof() and cin.good()) {
		cin >> x >> y;
		if (cin.eof()) {
			debug("EOF");
			break;
		}
		if (cin.good()) {
			Point p(x, y);
			vp.push_back(p);
			debug("LOOP[" << iterator++ << "] " << x << " " << y);
		} else {
			cerr << "INPUT ERROR" << endl;
			break;
		}
	}

	if (vp.size() > 1) {
		RRTStar rrt(vp[0], radius);
		rrt.iterate(vp);
		cout << rrt;
	}

	debug("END");
	return 0;
}

